data_utils
data_utils
Functions
| Name | Description |
|---|---|
get_data_folder_path |
Returns the absolute path to the data folder located in the package. |
load_compressor_data |
Loads the normalized compressor datasets X and Z. |
data_utils
| Name | Description |
|---|---|
get_data_folder_path |
Returns the absolute path to the data folder located in the package. |
load_compressor_data |
Loads the normalized compressor datasets X and Z. |