functions.rsm
functions.rsm
Functions
| Name | Description |
|---|---|
activity_pred |
Predicts the thermal activity based on the input vector x. |
conversion_pred |
Predicts the percent conversion based on the input vector x. |
rsm_opt |
Optimization function to calculate desirability. |